/*
 *  point.cpp
 *  johnWhitney
 *
 *  Created by Lucas Vickers on 9/20/10.
 *  Copyright 2010 None. All rights reserved.
 *
 */

#include "whitneyPoint.h"

WhitneyPoint::WhitneyPoint(float drawRadius, 
						   float rotationRadius, 
						   ofPoint origin, 
						   float rotationSpeed,
						   float RRModulation,
						   ofColor color,
						   ofColor colorSpeed,
						   float angleOffset) : 
drawRadius(drawRadius), 
rotationRadius(rotationRadius),
origin(origin),
currentOrigin(origin),
rotationSpeed(rotationSpeed),
curRotationSpeed(rotationSpeed),
RRModulation(RRModulation),
color(color),
colorSpeed(colorSpeed),
angleOffset(angleOffset),
curColor(color)
{

}

void WhitneyPoint::draw() 
{
	int recMode = ofGetRectMode();
	ofSetRectMode(OF_RECTMODE_CENTER);	
	
	ofSetColor(curColor.r, curColor.g, curColor.b, curColor.a);
	ofFill();
	ofCircle(curLocation.x, curLocation.y, drawRadius);
	
	ofSetRectMode(recMode);
}

void WhitneyPoint::update()
{
	float angle = ofGetElapsedTimef() * curRotationSpeed;
	
	// do a cos for radius so we start off full tilt, and if we do no modulation
	// it still works
	float radius = ofMap(cos(ofGetElapsedTimef()*RRModulation), -1, 1, rotationRadius*2/3, 
											 rotationRadius, true);
	
	
	curLocation.x = currentOrigin.x + radius * cos(angle + angleOffset);
	curLocation.y = currentOrigin.y + radius * -sin(angle + angleOffset);
	
	curColor.r = color.r + ofMap(sin(ofGetElapsedTimef()*colorSpeed.r), -1, 1, 
															 -color.r, 255 - color.r, true);
	curColor.g = color.g + ofMap(sin(ofGetElapsedTimef()*colorSpeed.g), -1, 1, 
															 -color.r, 255 - color.r, true);
	curColor.b = color.b + ofMap(sin(ofGetElapsedTimef()*colorSpeed.b), -1, 1, 
															 -color.r, 255 - color.r, true);
	curColor.a = color.a + ofMap(sin(ofGetElapsedTimef()*colorSpeed.a), -1, 1, 
															 -color.r, 255 - color.r, true);
}

void WhitneyPoint::setShake(float shake)
{
	currentOrigin.x = origin.x + ofRandom(-shake, shake);
	currentOrigin.y = origin.y + ofRandom(-shake, shake);
}

void WhitneyPoint::setRadius(float radius)
{
	drawRadius = radius;
}

void WhitneyPoint::setSpeedRatio(float ratio)
{
	curRotationSpeed = rotationSpeed * ratio;
}
